@@ -18,7 +18,7 @@ functional(m, eta2~eta1) <- f
 d <- sim(m, n=200, seed=42) # Default is all parameters are 1
 
 ## -----------------------------------------------------------------------------
-plot(m)
+plot(m, plot.engine="visNetwork")
 
 ## ----specifymodels------------------------------------------------------------
 m1 <- lvm(x1+x2+x3 ~ eta1, eta1 ~ z, latent=~eta1)
@@ -74,15 +74,15 @@ m2d <- nonlinear(m2, type="spline", knots=kn2, eta2~eta1)
 #  ## Repeated 5-fold cross-validation:
 #  ff <- lapply(list(linear=m2a,quadratic=m2b,spline4=m2c,spline6=m2d),
 #  	    function(m) function(data,...) twostage(m1,m,data=data,stderr=FALSE,control=list(start=coef(e0),contrain=TRUE)))
-#  fit.cv <- cv(ff,data=d,K=5,rep=2,mc.cores=parallel::detectCores(),seed=1)
+#  fit.cv <- lava:::cv(ff,data=d,K=5,rep=2,mc.cores=parallel::detectCores(),seed=1)
 
 ## ----results="hide", echo=FALSE-----------------------------------------------
 ## To save time building the vignettes on CRAN, we cache time consuming computations
 if (fullVignette) {
   fit.cv$fit <- NULL
-  saveRDS(fit.cv, "nonlinear_fitcv.rds")
+  saveRDS(fit.cv, "data/nonlinear_fitcv.rds")
 } else {
-  fit.cv <- readRDS("nonlinear_fitcv.rds")
+  fit.cv <- readRDS("data/nonlinear_fitcv.rds")
 }
 
 ## -----------------------------------------------------------------------------
@@ -114,9 +114,9 @@ legend("bottomright",
 ## ----results="hide", echo=FALSE-----------------------------------------------
 ## To save time building the vignettes on CRAN, we cache time consuming computations
 if (fullVignette) {
-  saveRDS(summary(selmod), "nonlinear_selmod.rds")
+  saveRDS(summary(selmod), "data/nonlinear_selmod.rds")
 } else {
-  selmod <- readRDS("nonlinear_selmod.rds")
+  selmod <- readRDS("data/nonlinear_selmod.rds")
 }
 
 ## -----------------------------------------------------------------------------
@@ -159,9 +159,9 @@ regression(m1,x1~eta1) <- 1 ## Factor loading fixed to 1
 ## ----results="hide", echo=FALSE-----------------------------------------------
 ## To save time building the vignettes on CRAN, we cache time consuming computations
 if (fullVignette) {
-  saveRDS(em0, "nonlinear_em0.rds")
+  saveRDS(em0, "data/nonlinear_em0.rds")
 } else {
-  em0 <- readRDS("nonlinear_em0.rds")
+  em0 <- readRDS("data/nonlinear_em0.rds")
 }
 
 ## -----------------------------------------------------------------------------
@@ -191,3 +191,6 @@ confband(pm[,1], lower=pm[,4], upper=pm[,5], polygon=TRUE,
 legend("bottomright", c("Gaussian","Mixture"),
        col=c("darkblue","darkred"), lwd=2, bty="n")
 
+## -----------------------------------------------------------------------------
+sessionInfo()
+
